@@ -272,7 +272,9 @@ class ORDF(Command):
     parser.add_option("--reindex", action="store_true",
                        dest="reindex", default=False,
                        help="Reindex indices reading from a single reader")
-
+    parser.add_option("--nocs", action="store_true",
+                      dest="nocs", default=False,
+                      help="Do not process changesets")
     def parse_config(self):
         super(ORDF, self).parse_config()
 
@@ -282,10 +284,12 @@ class ORDF(Command):
         if self.options.writers:
             self.config["ordf.writers"] = self.options.writers
 
-        if self.options.save and not self.options.message:
-            self.options.print_help()
-            print "ERROR: missing log message"
-            exit(1)
+        if not self.options.nocs:
+            if self.options.save or self.options.remove:
+                if not self.options.message:
+                    self.parser.print_help()
+                    print "ERROR: missing log message"
+                    exit(1)
 
         if self.options.reindex:
             reader = self.config.get("ordf.readers")
@@ -313,7 +317,9 @@ class ORDF(Command):
                 user = self.options.user
             else:
                 user = getuser()
-            ctx = self.handler.context(user, self.options.message)
+
+            if not self.options.nocs:
+                ctx = self.handler.context(user, self.options.message)
 
             agent = Agent()
             agent.nick(Literal(user))
@@ -346,13 +352,21 @@ class ORDF(Command):
                     proc.result(g)
 
                     self.log.info("add %s" % (g.identifier,))
+                    if self.options.nocs:
+                        self.handler.put(g)
+
                 elif self.options.remove:
                     self.log.info("del %s" % (g.identifier,))
+                    if self.options.nocs:
+                        self.handler.remove(g)
 
-                ctx.add(g)
+                if not self.options.nocs:
+                    ctx.add(g)
+
+            if not self.options.nocs:
+                self.log.info("commit changes")
+                cs = ctx.commit()
 
-            self.log.info("commit changes")
-            cs = ctx.commit()
         elif self.options.reindex:
             reader = getattr(self.handler, self.reindex_reader)
             for graph in reader:
