@@ -7,7 +7,7 @@ application will,
     3. Use the :meth:`get` and :meth:`put` methods to respectively retrieve
        and save *Graphs*.
     4. Use :meth:`context` to save *Graphs* within the context of a
-       :class:`ordf.changeset.ChangeSet`.
+       :class:`ordf.vocab.changeset.ChangeSet`.
 
 See the documentation for :class:`HandlerPlugin` for how handler
 the implementation works.
@@ -35,7 +35,7 @@ Making Changesets -- :class:`ChangeContext`
 """
 __all__ = ["Handler", "HandlerPlugin", "init_handler", "ConfigError"]
 
-from ordf.changeset import ChangeSet
+from ordf.vocab.changeset import ChangeSet
 from ordf.graph import Graph, _Graph, ConjunctiveGraph, _CGraph
 from ordf.namespace import namespaces, CS, RDF
 import pkg_resources
@@ -95,7 +95,9 @@ class ChangeContext(object):
         changeset and then for each of the new versions of the graphs in
         turn.
         """
-        cs = ChangeSet(*self.__av__, store=self.store, **self.__kw__)
+	kw = self.__kw__.copy()
+	kw["store"] = self.store
+        cs = ChangeSet(*self.__av__, **kw)
 
         ## we keep track if there is already a changeset in the store
         embedded_changeset = False
@@ -273,6 +275,13 @@ class Handler(object):
                 result.handler = self
                 return result
 
+    def append(self, *av, **kw):
+        """
+        Append to the given graph
+        """
+        for h in self.__writers__:
+            h.append(*av, **kw)
+            
     def remove(self, *av, **kw):
         """
         Remove the graph from all storage and indices
@@ -429,6 +438,17 @@ class HandlerPlugin(object):
         """
         return self[identifier]
 
+    def append(self, frag):
+        """
+        Append the fragment to the given graph
+        """
+        graph = self.handler.get(frag.identifier)
+        if graph is not None:
+            graph += frag
+        else:
+            graph = frag
+        self.put(graph)
+                                                
     def remove(self, identifier):
         """
         Remove the requested graph. Arguments as for :meth:get
