@@ -439,10 +439,12 @@ class Render(Command):
             doc += ET.tostring(child, encoding="utf-8")
         doc += '</html>'
 
-        from xml.dom import minidom
-        from StringIO import StringIO
-        doc = minidom.parse(StringIO(doc))
-        print doc.toprettyxml()
+        print doc
+
+    #    from xml.dom import minidom
+    #    from StringIO import StringIO
+    #    doc = minidom.parse(StringIO(doc))
+    #    print doc.toprettyxml()
 
 def render():
     Render().command()
