@@ -6,7 +6,7 @@ from logging import getLogger
 log = getLogger(__name__)
 
 def rdf_data():
-    graph_uri = RDFS[""][:-1]
+    graph_uri = RDFS[""]
     log.info("Fetching %s" % graph_uri)
     g = Graph(identifier=graph_uri).parse(graph_uri)
     log.info("Parsed %s (%d triples)" % (graph_uri, len(g)))
@@ -18,4 +18,13 @@ def inference_rules(handler, network):
     rules = HornFromN3(rule_file)
     for rule in rules:
         network.buildNetworkFromClause(rule)
-    return rules
+
+    from FuXi.DLP.DLNormalization import NormalFormReduction
+    rdfs = handler.get(RDFS[""])
+    if len(rdfs) == 0:
+        for rdfs in rdf_data():
+            pass
+    NormalFormReduction(rdfs)
+    dlp = network.setupDescriptionLogicProgramming(rdfs, addPDSemantics=True)
+
+    return list(rules) + dlp
